@@ -60,6 +60,8 @@ class UserApi:
         """
         ret = {}
         mast = self.user_creator(name, other_fields)
+        if type(mast) is dict:
+            return mast
         ret["user"] = mast.serialize()
         self.seek_committer(mast)
         if len(global_init):
@@ -69,6 +71,36 @@ class UserApi:
         ret["success"] = True
         return ret
 
+    @Interface.admin_api(cli_args=["name"])
+    def user_delete(self, name: str):
+        """
+        Delete new user (master object)
+
+        This API is used to delete a user account.
+
+        :param name: The user name to delete. For Jaseci server this must
+        be a valid email address.
+
+        """
+        ret = {}
+        ret["success"] = self.user_destroyer(name)
+        if not ret["success"]:
+            ret["status_code"] = 400
+        return ret
+
+    @Interface.private_api(cli_args=["name"])
+    def user_deleteself(self):
+        """
+        Delete self (master object)
+
+        This API is used to delete a user account.
+        """
+        ret = {}
+        ret["success"] = self.user_destroyer(self.name)
+        if not ret["success"]:
+            ret["status_code"] = 400
+        return ret
+
     def user_creator(self, name, other_fields: dict = {}):
         """
         Abstraction for user creation for elegant overriding
