@@ -26,3 +26,20 @@ class CoreTest(TestCaseHelper, TestCase):
     def load_jac(self, fn):
         with open(os.path.dirname(self.fixture_src) + "/fixtures/" + fn) as f:
             return f.read()
+
+
+def jac_testcase(jac_file: str, test_name: str):
+    """decorator for test cases"""
+
+    def decorator(func):
+        def wrapper(self):
+            self.call(
+                self.mast,
+                ["sentinel_register", {"code": self.load_jac(jac_file)}],
+            )
+            ret = self.call(self.mast, ["walker_run", {"name": test_name}])
+            func(self, ret)
+
+        return wrapper
+
+    return decorator
