@@ -42,10 +42,12 @@ def connect_logger_handler(target_logger, handler, level=logging.WARN):
 
 
 logger = logging.getLogger("core")
+logger.propagate = False
 if len(logger.handlers) < 1:
     connect_logger_handler(logger, logging.StreamHandler(), logging.INFO)
 
 app_logger = logging.getLogger("app")
+app_logger.propagate = False
 if len(app_logger.handlers) < 1:
     connect_logger_handler(app_logger, logging.StreamHandler(), logging.INFO)
 
